```
<# process a raw T2 png, and save the prostate region, rostate with contour in './media/output/'

def predict(image_path):

    MODEL_DIR = './doc/weights/'
    Prostate_WEIGHTS_PATH = "weight1.h5"  # TODO: update this path

    class InferenceConfig(ProstateConfig):
        # Run detection on one image at a time
        GPU_COUNT = 1
        IMAGES_PER_GPU = 1

    config = InferenceConfig()
    config.display()

    DEVICE = "/cpu:0"  # /cpu:0 or /gpu:0 or /gpu:1

    with tf.device(DEVICE):
        model = MaskRCNN(mode="inference", model_dir=MODEL_DIR,
                                  config=config)

    weights_path = MODEL_DIR + Prostate_WEIGHTS_PATH

    model.load_weights(weights_path, by_name=True)

    class_names = ['BG', 'pz', 'cg', 'prostate', 'cap']
    import skimage
    image = skimage.io.imread(image_path)
    if image.ndim != 3:
        image = skimage.color.gray2rgb(image)
    # If has an alpha channel, remove it for consistency
    if image.shape[-1] == 4:
        image = image[..., :3]

    h,w=image.shape[0],image.shape[1]
    image, window, scale, padding, crop = resize_image(
        image,
        min_dim=config.IMAGE_MIN_DIM,
        min_scale=config.IMAGE_MIN_SCALE,
        max_dim=config.IMAGE_MAX_DIM,
        mode=config.IMAGE_RESIZE_MODE)

    results = model.detect([image], verbose=1)

    # Display results

    r = results[0]
    index_pz = None
    index_cg = None
    index_prostate = None
    index_cap = None
    if len(results[0]['rois']) > 1:
        for i in range(len(results[0]['class_ids'])):
            if r['class_ids'][i] == 1:
                if index_pz == None:
                    index_pz = i
                else:
                    continue

            if r['class_ids'][i] == 2:
                if index_cg == None:
                    index_cg = i
                else:
                    continue

            if r['class_ids'][i] == 3:
                if index_prostate == None:
                    index_prostate = i
                else:
                    continue

            if r['class_ids'][i] == 4:
                if index_cap == None:
                    index_cap = i
                else:
                    continue

        list_index = []
        for index in [index_pz, index_cg, index_prostate, index_cap]:
            if index != None:
                list_index.append(index)

        if len(list_index) > 1:
            rois = results[0]['rois'][list_index[0]].reshape(1, -1)
            masks = results[0]['masks'][:, :, list_index[0]].reshape(512, 512, 1)
            class_ids = results[0]['class_ids'][list_index[0]].reshape(1, -1)
            scores = results[0]['scores'][list_index[0]].reshape(1, -1)

            for i in range(len(list_index) - 1):
                rois = np.concatenate((rois, results[0]['rois'][list_index[i + 1]].reshape(1, -1)), axis=0).reshape(
                    -1, 4)
                masks = np.concatenate((masks, results[0]['masks'][:, :, list_index[i + 1]].reshape(512, 512, 1)),
                                       axis=2).reshape(512, 512, -1)
                class_ids = np.concatenate((class_ids, results[0]['class_ids'][list_index[i + 1]].reshape(1, -1)),
                                           axis=0).reshape(-1, 1)
                scores = np.concatenate((scores, results[0]['scores'][list_index[i + 1]].reshape(1, -1)),
                                        axis=0).reshape(-1, 1)

            r['rois'] = rois
            r['masks'] = masks
            r['class_ids'] = class_ids.reshape(-1)
            r['scores'] = scores.reshape(-1)

        else:
            r['rois'] = results[0]['rois'][0].reshape(-1, 4)
            r['masks'] = results[0]['masks'][:, :, 0].reshape(512, 512, 1)
            r['class_ids'] = results[0]['class_ids'][0].reshape(-1)
            r['scores'] = results[0]['scores'][0].reshape(-1)

    x1, y1, x2, y2 = 0, 0, 0, 0
    save_path = './media/output/'

    if len(r['rois']) != 0:

        for object in range(len(r['rois'])):
            roi = r['rois'][object]
            mask = r['masks'][:, :, object]
            mask = mask + 0
            mask = mask * 255
            mask = np.array(mask, dtype='int8')

            class_id = r['class_ids'][object]

            from PIL import Image

            if class_id==3:
                Image.fromarray(mask, mode='L').resize((w, h)).save(
                    save_path + str(class_names[class_id])+'.png')

                mask_image=Image.open(save_path + str(class_names[class_id])+'.png')
                mask=np.array(mask_image)
                raw_image=Image.open(image_path).convert('L')

                contour = measure.find_contours(mask, 100)

                image_with_contour = cv2.cvtColor(np.array(raw_image), cv2.COLOR_GRAY2BGR)
                color = (0, 255, 255)

                prostate_contour = []
                
                ratio = w / 512
                
                #cv2.circle(image_with_contour,(283,287),20,(0,255,255),thickness=-1)
                #cv2.circle(image,(int(283/ratio),int(287/ratio)),20,(0,255,255),thickness=-1)

                for c in contour[0]:
                    c = np.around(c).astype(np.int)
                    prostate_contour.append(np.array([c[1], c[0]]))

                cv2.drawContours(image_with_contour, [np.array(prostate_contour)], -1, color, thickness=2)

                raw_image.save(save_path +'raw.png')

                cv2.imwrite(save_path + 'contour.png', image_with_contour)
                prostate_roi=image[roi[0]:roi[2],roi[1]:roi[3]]
                #prostate_roi=image_with_contour[roi[0]:roi[2],roi[1]:roi[3]]

                cv2.imwrite(save_path+'prostate_roi.png',prostate_roi)

                ratio = w / 512
                x1 = int(str(roi[0])) * ratio
                y1 = int(str(roi[1])) * ratio
                x2 = int(str(roi[2])) * ratio
                y2 = int(str(roi[3])) * ratio

    del model
    K.clear_session()
    gc.collect()
    # print('done!')
    return x1, y1, x2, y2>
```